pub enum GroqError {
InvalidRequest(String),
RequestFailed(Error),
JsonParseError(Error),
ApiError {
message: String,
type_: String,
},
DeserializationError {
message: String,
type_: String,
},
}Expand description
Represents errors that can occur when interacting with the GROQ API.
RequestFailed: Indicates a failure in the underlying HTTP request.JsonParseError: Indicates a failure in parsing the JSON response from the API.ApiError: Indicates an error returned by the API, with a message and error type.DeserializationError: Indicates an error with deserialization, with a message and error type.
Variants